Usage
volcanoplot(x,
labels = "",
p.value = "pval",
mask = FALSE,
show.cutoff = TRUE,
cex.text = 0.7,
col.text = "blue",
col.cutoff = "grey",
xlim = NULL,
xlab = "Log2(Fold-Change)",
ylab = "-Log10(P-Value)",
pch = '.',
...)
AnalysisTreeSet.TRUE draw only points for transcripts satisfying the univariate test.TRUE draw lines indicating cutoff.labels.labels.show.cutoff=TRUE.plot.data for an object of class AnalysisTreeSet. It is possible to label the points of the volcano plot, whereby the following
labels parameters are valid:
fUnitName: |
|
| unit name (probeset ID). | |
fName: |
gene name. |
fSymbol: |
|
| gene symbol. | |
fChromosome: |
chromosome. |